import {
  select,
  csv,
  scaleLinear,
  extent,
  scaleBand,
  axisLeft,
  axisBottom,
  format,
  max, scaleOrdinal
} from 'd3';


// set the dimensions and margins of the graph
var margin = {top: 20, right: 50, bottom: 25, left: 60};
var width = 600 - margin.left - margin.right;
var height = 400 - margin.top - margin.bottom;
    
var svg= select('#my_dataviz')
.append('svg')
.attr("width", width - margin.left - margin.right)
.attr("height", height - margin.top - margin.bottom)
.append("g")
.attr("transform","translate(" + margin.left + "," + margin.top + ")");

csv('data.csv').then(data => {
data.forEach(d => {
d.Lesedi = +d.Lesedi;
d.meter1=+d.meter1;
d.meter2=+d.meter2; 
});
  
var TelescopeNames= data.columns.slice(1)
var groups= data.map(function(d){return d.Months})
//now for the scales
const xScale= scaleBand()
.domain(groups)
.range([0, width])
.padding(0.2)
const yScale=scaleLinear()
.domain([0,600])
.range([height,0])

//Another scale for subgroup position
const xSubgroup= scaleBand()
.domain(TelescopeNames)
.range([0, xScale.bandwidth()])  

const color= scaleOrdinal()
.domain(TelescopeNames)
.range('#e41a1c','#377eb8','#4daf4a')

var xAxis=svg.append('g')
.classed('xAxis',true)
.attr('transform',`translate(${margin.left},${innerHeight+margin.top})`)
.call(d3.axisBottom(xScale))

var yAxis= svg.append('g')
.classed('yAxis',true)
.attr('transform',`translate(${margin.left},${margin.top})`)
.call(d3.axisLeft(yScale))


svg.append("g")
   .selectAll("g")
// Enter in data = loop group per group
.data(data)
.enter()
.append("g")
.attr("transform", function(d) { return "translate(" + xScale(d.Months) + ",0)"; })
.selectAll("rect")
.data(function(d) { return TelescopeNames.map(function(key) { return {key: key, value: d[key]}; }); })
.enter().append("rect")
.attr("x", function(d) { return xSubgroup(d.key); })
.attr("y", function(d) { return yScale(d.value); })
.attr("width", xSubgroup.bandwidth())
.attr("height", function(d) { return height - yScale(d.value); })
.attr("fill", function(d) { return color(d.key); 
});
console.log(color.range())
console.log(TelescopeNames)  
});



